syntax = "proto3";

import "google/protobuf/wrappers.proto";

import "google/protobuf/timestamp.proto";

package discord_protos.users.v1;

message UserData {
  enum UserLinkType {
    USER_LINK_TYPE_UNSPECIFIED = 0;
    USER_LINK_TYPE_PARENT = 1;
    USER_LINK_TYPE_CHILD = 2;
  }

  enum UserLinkStatus {
    USER_LINK_STATUS_UNSPECIFIED = 0;
    USER_LINK_STATUS_PENDING = 1;
    USER_LINK_STATUS_ACTIVE = 2;
    USER_LINK_STATUS_INACTIVE = 3;
    USER_LINK_STATUS_DECLINED = 4;
  }

  message LinkedUser {
    fixed64 user_id = 1;
    UserLinkType link_type = 2;
    UserLinkStatus link_status = 3;
    fixed64 requestor_id = 4;
    optional google.protobuf.Timestamp created_at = 5;
    optional google.protobuf.Timestamp updated_at = 6;
  }

  message RateLimitData {
    optional google.protobuf.Timestamp limit_expiry = 1;
  }

  message FeatureLimits {
    map<uint32, RateLimitData> map = 1;
  }

  message SafetyFlag {
    optional google.protobuf.Timestamp flag_expiry = 1;
  }

  message QuestMetadata {
    uint32 quests_completed = 1;
  }

  message UserPrimaryGuild {
    optional google.protobuf.UInt64Value identity_guild_id = 1;
    optional google.protobuf.BoolValue identity_enabled = 2;
    optional google.protobuf.StringValue tag = 3;
    optional google.protobuf.StringValue badge = 4;
  }

  message CrossPlatformRestriction {
    optional google.protobuf.Timestamp restriction_expiry = 1;
    fixed64 application_id = 2;
  }

  message UserNameplate {
    string asset = 1;
    string palette = 2;
    optional google.protobuf.UInt64Value sku_id = 3;
    optional google.protobuf.Timestamp expires_at = 4;
    string label = 5;
  }

  message UserCollectibles {
    optional UserNameplate nameplate = 1;
  }

  message NormalState {
  }

  message RestrictedState {
    optional google.protobuf.Timestamp restricted_until = 1;
  }

  message DeferredActionState {
    optional google.protobuf.Timestamp action_deferred_until = 1;
  }

  enum ClassificationType {
    CLASSIFICATION_TYPE_UNSPECIFIED = 0;
    CLASSIFICATION_TYPE_UNKNOWN = 1;
    CLASSIFICATION_TYPE_UNSOLICITED_PORNOGRAPHY = 100;
    CLASSIFICATION_TYPE_NONCONSENSUAL_PORNOGRAPHY = 200;
    CLASSIFICATION_TYPE_GLORIFYING_VIOLENCE = 210;
    CLASSIFICATION_TYPE_HATE_SPEECH = 220;
    CLASSIFICATION_TYPE_CRACKED_ACCOUNTS = 230;
    CLASSIFICATION_TYPE_ILLICIT_GOODS = 240;
    CLASSIFICATION_TYPE_SOCIAL_ENGINEERING = 250;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SAFETY_DISPATCH = 260;
    CLASSIFICATION_TYPE_UNDERAGE_USER_SAFETY_DISPATCH = 270;
    CLASSIFICATION_TYPE_CSAM_SAFETY_DISPATCH = 280;
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 286;
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_SAFETY_DISPATCH = 290;
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 296;
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_SAFETY_DISPATCH = 300;
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 306;
    CLASSIFICATION_TYPE_HARASSMENT_AND_THREATS_SAFETY_DISPATCH = 310;
    CLASSIFICATION_TYPE_HATE_SPEECH_SAFETY_DISPATCH = 320;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 326;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_SAFETY_DISPATCH = 330;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 336;
    CLASSIFICATION_TYPE_REGULATED_GOODS_HIGH_RISK_SAFETY_DISPATCH = 340;
    CLASSIFICATION_TYPE_REGULATED_GOODS_MEDIUM_RISK_SAFETY_DISPATCH = 350;
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 356;
    CLASSIFICATION_TYPE_REGULATED_GOODS_LOW_RISK_SAFETY_DISPATCH = 360;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_SAFETY_DISPATCH = 370;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 376;
    CLASSIFICATION_TYPE_FINANCIAL_SCAMS_SAFETY_DISPATCH = 380;
    CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_SAFETY_DISPATCH = 390;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH = 400;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 406;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_SAFETY_DISPATCH = 410;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 416;
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_SAFETY_DISPATCH = 420;
    CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_HASH_MATCH = 500;
    CLASSIFICATION_TYPE_CSAM_HIGH_CONFIDENCE_HASH_MATCH = 501;
    CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_SAFETY_DISPATCH = 510;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_SAFETY_DISPATCH = 520;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 526;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_SAFETY_DISPATCH = 530;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 536;
    CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH = 540;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH = 550;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 556;
    CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_SAFETY_DISPATCH = 560;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_SAFETY_DISPATCH = 570;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 576;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_SAFETY_DISPATCH = 580;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 586;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_SAFETY_DISPATCH = 590;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 596;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_SAFETY_DISPATCH = 600;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_API = 601;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 606;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_SAFETY_DISPATCH = 610;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_SAFETY_DISPATCH = 620;
    CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_SAFETY_DISPATCH = 630;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_SAFETY_DISPATCH = 640;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_API = 641;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 646;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_SAFETY_DISPATCH = 650;
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_HASH_MATCH = 660;
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_SAFETY_DISPATCH = 661;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_SAFETY_DISPATCH = 670;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 676;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_SAFETY_DISPATCH = 680;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 686;
    CLASSIFICATION_TYPE_IMPERSONATION_SAFETY_DISPATCH = 5726;
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SAFETY_DISPATCH = 5727;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SAFETY_DISPATCH = 690;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 696;
    CLASSIFICATION_TYPE_PHISHING_SAFETY_DISPATCH = 700;
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SMITE = 710;
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SAFETY_DISPATCH = 711;
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_ADMIN = 712;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_SMITE = 720;
    CLASSIFICATION_TYPE_GENERIC_CHILD_SELF_ENDANGERMENT_SAFETY_DISPATCH = 730;
    CLASSIFICATION_TYPE_GENERIC_CSAM_AND_CHILD_SEXUALIZATION_SAFETY_DISPATCH = 740;
    CLASSIFICATION_TYPE_GENERIC_INAPPROPRIATE_SEXUAL_CONDUCT_WITH_CHILDREN_AND_GROOMING_SAFETY_DISPATCH = 750;
    CLASSIFICATION_TYPE_GENERIC_FINANCIAL_SCAMS_SAFETY_DISPATCH = 760;
    CLASSIFICATION_TYPE_GENERIC_FRAUD_SERVICES_SAFETY_DISPATCH = 770;
    CLASSIFICATION_TYPE_GENERIC_BULLYING_HARASSMENT_AND_THREATS_SAFETY_DISPATCH = 780;
    CLASSIFICATION_TYPE_GENERIC_HATE_SPEECH_SAFETY_DISPATCH = 790;
    CLASSIFICATION_TYPE_GENERIC_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH = 800;
    CLASSIFICATION_TYPE_GENERIC_SELF_HARM_ENCOURAGEMENT_AND_PROMOTION_SAFETY_DISPATCH = 810;
    CLASSIFICATION_TYPE_GENERIC_GLORIFICATION_AND_INCITEMENT_OF_VIOLENCE_SAFETY_DISPATCH = 820;
    CLASSIFICATION_TYPE_GENERIC_CYBERCRIME_SAFETY_DISPATCH = 830;
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 846;
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_SAFETY_DISPATCH = 850;
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 856;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 866;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 876;
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 886;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_SAFETY_DISPATCH = 890;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH = 895;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 896;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH = 900;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH = 905;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 906;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_SAFETY_DISPATCH = 910;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH = 915;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 916;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH = 920;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH = 925;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 926;
    CLASSIFICATION_TYPE_GORE_SAFETY_DISPATCH = 930;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 936;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_SAFETY_DISPATCH = 940;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_SAFETY_DISPATCH = 945;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 946;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_SAFETY_DISPATCH = 950;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_SAFETY_DISPATCH = 955;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 956;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_SAFETY_DISPATCH = 960;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_SAFETY_DISPATCH = 965;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 966;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_SAFETY_DISPATCH = 970;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_SAFETY_DISPATCH = 975;
    CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 976;
    CLASSIFICATION_TYPE_AGE_RESTRICTED_CONTENT_IN_SERVER_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 986;
    CLASSIFICATION_TYPE_CSAM_SMITE = 3000;
    CLASSIFICATION_TYPE_CSAM_GUILD_SMITE = 3005;
    CLASSIFICATION_TYPE_SUSPICIOUS_LINK_SMITE = 3010;
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SMITE = 3020;
    CLASSIFICATION_TYPE_SPAM_SMITE = 3030;
    CLASSIFICATION_TYPE_SPAM_CEILING_SMITE = 3120;
    CLASSIFICATION_TYPE_VOLUMETRIC_ABUSE_SMITE = 3130;
    CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_SMITE = 3040;
    CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_SMITE = 3050;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_SMITE = 3065;
    CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_SMITE = 3075;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SMITE = 3085;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_SMITE = 3090;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SMITE = 3091;
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_SMITE = 3100;
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_SMITE = 3110;
    CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_HIGH_RISK = 4000;
    CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_MEDIUM_RISK = 4010;
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_VERY_HIGH_RISK = 4100;
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_HIGH_RISK = 4110;
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_MEDIUM_RISK = 4120;
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_LOW_RISK = 4130;
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_COPYRIGHT = 4140;
    CLASSIFICATION_TYPE_OWNER_OF_INAUTHENTIC_ENGAGEMENT_GUILD = 4150;
    CLASSIFICATION_TYPE_CSAM_ADMIN = 5000;
    CLASSIFICATION_TYPE_CSAM_GUILD_ADMIN = 5005;
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_ADMIN = 5006;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_ADMIN = 5010;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_ADMIN = 5015;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_ADMIN = 5016;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_ADMIN = 5020;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_ADMIN = 5025;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_ADMIN = 5026;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_ADMIN = 5030;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_ADMIN = 5035;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_ADMIN = 5036;
    CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_ADMIN = 5040;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_ADMIN = 5050;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_ADMIN = 5055;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_ADMIN = 5060;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_GUILD_ADMIN = 5065;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_ADMIN = 5070;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_ADMIN = 5075;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_ADMIN = 5076;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_ADMIN = 5080;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_ADMIN = 5085;
    CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_ADMIN = 5090;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_ADMIN = 5100;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_ADMIN = 5105;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_ADMIN = 5106;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_ADMIN = 5110;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_ADMIN = 5115;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_ADMIN = 5116;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_ADMIN = 5120;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_ADMIN = 5125;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_ADMIN = 5126;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_ADMIN = 5130;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_ADMIN = 5135;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_ADMIN = 5136;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_ADMIN = 5140;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_ADMIN = 5145;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_ADMIN = 5146;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_ADMIN = 5150;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_ADMIN = 5155;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_ADMIN = 5156;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_ADMIN = 5160;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_ADMIN = 5165;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_ADMIN = 5166;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_ADMIN = 5170;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_ADMIN = 5175;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_ADMIN = 5176;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_ADMIN = 5180;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_ADMIN = 5185;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_ADMIN = 5186;
    CLASSIFICATION_TYPE_RISK_OF_PHYSICAL_SELF_HARM_ADMIN = 5190;
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_ADMIN = 5200;
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_GUILD_ADMIN = 5205;
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_ADMIN = 5206;
    CLASSIFICATION_TYPE_GORE_ADMIN = 5210;
    CLASSIFICATION_TYPE_GORE_GUILD_ADMIN = 5215;
    CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_ADMIN = 5216;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_ADMIN = 5220;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_ADMIN = 5225;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_ADMIN = 5226;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_ADMIN = 5230;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_ADMIN = 5235;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_ADMIN = 5236;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_ADMIN = 5240;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_ADMIN = 5245;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_ADMIN = 5246;
    CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_ADMIN = 5250;
    CLASSIFICATION_TYPE_SERVER_RAIDS_ADMIN = 5260;
    CLASSIFICATION_TYPE_SERVER_RAIDS_GUILD_ADMIN = 5265;
    CLASSIFICATION_TYPE_SERVER_RAIDS_NON_DEDICATED_GUILD_ADMIN = 5266;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_ADMIN = 5270;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_GUILD_ADMIN = 5275;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_NON_DEDICATED_GUILD_ADMIN = 5276;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_ADMIN = 5280;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_ADMIN = 5285;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_ADMIN = 5286;
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_ADMIN = 5290;
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_GUILD_ADMIN = 5295;
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_ADMIN = 5296;
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_ADMIN = 5300;
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_GUILD_ADMIN = 5305;
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_ADMIN = 5306;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_ADMIN = 5310;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_ADMIN = 5315;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_ADMIN = 5316;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_ADMIN = 5320;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_ADMIN = 5325;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_ADMIN = 5326;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_ADMIN = 5330;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_ADMIN = 5335;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_ADMIN = 5340;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_ADMIN = 5344;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_ADMIN = 5346;
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN = 5350;
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN = 5355;
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN = 5360;
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN = 5365;
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN = 5366;
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN = 5370;
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN = 5375;
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN = 5376;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_ADMIN = 5380;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_ADMIN = 5385;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_ADMIN = 5386;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_ADMIN = 5390;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_ADMIN = 5395;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_NON_DEDICATED_GUILD_ADMIN = 5396;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_ADMIN = 5400;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_ADMIN = 5405;
    CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_ADMIN = 5410;
    CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_API = 5411;
    CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_ADMIN = 5420;
    CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_ADMIN = 5430;
    CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_NON_DEDICATED_GUILD_ADMIN = 5436;
    CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_ADMIN = 5440;
    CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_NON_DEDICATED_GUILD_ADMIN = 5446;
    CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_ADMIN = 5450;
    CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_NON_DEDICATED_GUILD_ADMIN = 5456;
    CLASSIFICATION_TYPE_TRADEMARK_ADMIN = 5460;
    CLASSIFICATION_TYPE_TRADEMARK_GUILD_ADMIN = 5465;
    CLASSIFICATION_TYPE_TRADEMARK_NON_DEDICATED_GUILD_ADMIN = 5466;
    CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_ADMIN = 5470;
    CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_NON_DEDICATED_GUILD_ADMIN = 5476;
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_ADMIN = 5480;
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_GUILD_ADMIN = 5485;
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_NON_DEDICATED_GUILD_ADMIN = 5486;
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_ADMIN = 5490;
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_GUILD_ADMIN = 5495;
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN = 5496;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_ADMIN = 5500;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_ADMIN = 5505;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN = 5506;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_ADMIN = 5510;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_ADMIN = 5515;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_ADMIN = 5516;
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_ADMIN = 5520;
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_ADMIN = 5525;
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_ADMIN = 5530;
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_GUILD_ADMIN = 5535;
    CLASSIFICATION_TYPE_PHISHING_ADMIN = 5540;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_ADMIN = 5550;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_ADMIN = 5555;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_ADMIN = 5556;
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_ADMIN = 5560;
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_GUILD_ADMIN = 5565;
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_NON_DEDICATED_GUILD_ADMIN = 5566;
    CLASSIFICATION_TYPE_MONEY_LAUNDERING_ADMIN = 5570;
    CLASSIFICATION_TYPE_MONEY_LAUNDERING_GUILD_ADMIN = 5575;
    CLASSIFICATION_TYPE_FORGERY_ADMIN = 5580;
    CLASSIFICATION_TYPE_FORGERY_GUILD_ADMIN = 5585;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_ADMIN = 5590;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_ADMIN = 5595;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_NON_DEDICATED_GUILD_ADMIN = 5596;
    CLASSIFICATION_TYPE_MISLEADING_ABUSE_REPORTS_ADMIN = 5600;
    CLASSIFICATION_TYPE_FRAUDULENT_LEGAL_PROCESS_ADMIN = 5610;
    CLASSIFICATION_TYPE_HARASSMENT_OF_DISCORDS_SUPPORT_TEAMS_ADMIN = 5620;
    CLASSIFICATION_TYPE_IMPERSONATION_ADMIN = 5630;
    CLASSIFICATION_TYPE_IMPERSONATION_GUILD_ADMIN = 5635;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_ADMIN = 5640;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_ADMIN = 5645;
    CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_ADMIN = 5650;
    CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_GUILD_ADMIN = 5655;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_ADMIN = 5660;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_GUILD_ADMIN = 5665;
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_ADMIN = 5666;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_ADMIN = 5670;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_ADMIN = 5675;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_ADMIN = 5676;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_ADMIN = 5680;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_ADMIN = 5685;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_NON_DEDICATED_GUILD_ADMIN = 5686;
    CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_ADMIN = 5695;
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_ADMIN = 5700;
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_ADMIN = 5705;
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_ADMIN = 5706;
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN = 5716;
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN = 5735;
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_ADMIN = 5740;
    CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_ADMIN = 5750;
    CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_ADMIN = 5760;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_ADMIN = 5770;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_ADMIN = 5775;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN = 5776;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_ADMIN = 5780;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN = 5785;
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN = 5786;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_ADMIN = 5790;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_ADMIN = 5795;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN = 5796;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_ADMIN = 5800;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN = 5805;
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN = 5806;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_ADMIN = 5810;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_ADMIN = 5815;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_ADMIN = 5816;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_ADMIN = 5820;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_ADMIN = 5830;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_ADMIN = 5825;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_ADMIN = 5835;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_ADMIN = 5826;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_ADMIN = 5836;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_ADMIN = 5840;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_ADMIN = 5845;
    CLASSIFICATION_TYPE_DENIED_PARTY_SCREENING_ADMIN = 5850;
    CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_ADMIN = 5865;
    CLASSIFICATION_TYPE_FRAUDULENT_CHARGE_ADMIN = 5870;
    CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_ADMIN = 5880;
    CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD_ADMIN = 5885;
    CLASSIFICATION_TYPE_PRESENCE_IN_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD = 5920;
    CLASSIFICATION_TYPE_OWNER_OF_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD = 5930;
    CLASSIFICATION_TYPE_UNAUTHORIZED_TRANSACTION_ADMIN = 5890;
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_ADMIN = 5900;
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_ADMIN = 5910;
    CLASSIFICATION_TYPE_SPAM_CEILING_ADMIN = 5940;
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL = 7005;
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL = 7015;
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL = 7025;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_RETOOL = 7035;
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_RETOOL = 7045;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_RETOOL = 7055;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_RETOOL = 7065;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_RETOOL = 7075;
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_RETOOL = 7085;
    CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_RETOOL = 7095;
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_RETOOL = 7105;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_RETOOL = 7110;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_RETOOL = 7120;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_RETOOL = 7130;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_RETOOL = 7140;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_RETOOL = 7150;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_RETOOL = 7160;
    CLASSIFICATION_TYPE_CSAM_RETOOL = 7170;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_RETOOL = 7180;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_RETOOL = 7190;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_RETOOL = 7115;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_RETOOL = 7125;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_RETOOL = 7135;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_RETOOL = 7145;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_RETOOL = 7155;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_RETOOL = 7165;
    CLASSIFICATION_TYPE_CSAM_GUILD_RETOOL = 7175;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_RETOOL = 7185;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_RETOOL = 7195;
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_RETOOL = 7116;
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_NON_DEDICATED_GUILD_RETOOL = 7126;
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_RETOOL = 7136;
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_RETOOL = 7146;
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_RETOOL = 7156;
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_RETOOL = 7166;
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_RETOOL = 7176;
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_RETOOL = 7186;
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_RETOOL = 7196;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_RETOOL = 7200;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_RETOOL = 7210;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_RETOOL = 7220;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_RETOOL = 7230;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_RETOOL = 7240;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_RETOOL = 7250;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_RETOOL = 7260;
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL = 7270;
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL = 7280;
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_RETOOL = 7290;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_RETOOL = 7300;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_RETOOL = 7060;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_RETOOL = 7310;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_RETOOL = 7320;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_RETOOL = 7330;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_RETOOL = 7340;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_RETOOL = 7350;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_RETOOL = 7360;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_RETOOL = 7370;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_RETOOL = 7380;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_RETOOL = 7390;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_RETOOL = 7400;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_RETOOL = 7410;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_RETOOL = 7420;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_RETOOL = 7430;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_RETOOL = 7440;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_RETOOL = 7205;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_RETOOL = 7215;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_RETOOL = 7225;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_RETOOL = 7235;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_RETOOL = 7245;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_RETOOL = 7255;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_RETOOL = 7265;
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL = 7275;
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL = 7285;
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_GUILD_RETOOL = 7295;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_RETOOL = 7305;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_RETOOL = 7315;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_RETOOL = 7325;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_GUILD_RETOOL = 7335;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_RETOOL = 7345;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_RETOOL = 7355;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_RETOOL = 7365;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_RETOOL = 7375;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_RETOOL = 7385;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_RETOOL = 7395;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_RETOOL = 7405;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_RETOOL = 7415;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_RETOOL = 7425;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_RETOOL = 7435;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_RETOOL = 7445;
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_RETOOL = 7206;
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_RETOOL = 7216;
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_RETOOL = 7226;
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_RETOOL = 7236;
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_RETOOL = 7246;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_RETOOL = 7256;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_RETOOL = 7266;
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL = 7276;
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL = 7286;
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_NON_DEDICATED_GUILD_RETOOL = 7296;
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_NON_DEDICATED_GUILD_RETOOL = 7306;
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_NON_DEDICATED_GUILD_RETOOL = 7066;
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_RETOOL = 7316;
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_RETOOL = 7326;
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_NON_DEDICATED_GUILD_RETOOL = 7336;
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_RETOOL = 7346;
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_RETOOL = 7356;
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_RETOOL = 7366;
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_NON_DEDICATED_GUILD_RETOOL = 7376;
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_RETOOL = 7386;
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_RETOOL = 7396;
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_RETOOL = 7406;
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_RETOOL = 7416;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_NON_DEDICATED_GUILD_RETOOL = 7426;
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_RETOOL = 7436;
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_RETOOL = 7446;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_RETOOL = 7450;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_RETOOL = 7460;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_RETOOL = 7455;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_RETOOL = 7465;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_RETOOL = 7456;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_RETOOL = 7466;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_RETOOL = 7470;
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_RETOOL = 7475;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_SAFETY_DISPATCH = 7480;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_SAFETY_DISPATCH = 7486;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_ADMIN = 7490;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_ADMIN = 7496;
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_HASH_MATCH = 7500;
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION = 9000;
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION_LOW = 9001;
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION_SEVERE = 9002;
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION = 9100;
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_LOW = 9101;
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_SEVERE = 9102;
    CLASSIFICATION_TYPE_TEST_PROVISIONAL_ACCOUNT_CLASSIFICATION = 9200;
  }

  message TempBannedState {
    optional google.protobuf.Timestamp banned_until = 1;
    repeated ClassificationType classification_types = 2;
  }

  message BannedState {
    repeated ClassificationType classification_types = 1;
  }

  enum SafetyStateReason {
    SAFETY_STATE_REASON_REASON_UNSPECIFIED = 0;
    SAFETY_STATE_REASON_DISABLED_SUSPICIOUS_ACTIVITY = 1;
    SAFETY_STATE_REASON_SMITE_REMOVE_EMAIL_VERIFICATION = 2;
    SAFETY_STATE_REASON_USER_REQUIRED_VERIFICATION_INTERVENTIONS_CLIENT = 3;
    SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_COMPLETED = 4;
    SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_CREATED = 5;
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CREATED = 6;
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_UPGRADED_TO_ACTIVE = 7;
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CANCELLED = 8;
    SAFETY_STATE_REASON_ASSIGNMENT_STATE_REPAIRED = 9;
    SAFETY_STATE_REASON_MANUAL_PERMANENT_BAN = 10;
    SAFETY_STATE_REASON_SAFETY_SYSTEM_UNBAN = 11;
    SAFETY_STATE_REASON_GENERIC_AUTOMATED_SAFETY_ACTION = 12;
    SAFETY_STATE_REASON_GENERIC_MANUAL_SAFETY_ACTION = 13;
    SAFETY_STATE_REASON_BANNED_USER_BACKFILL = 14;
  }

  enum SafetyAnnotations {
    SAFETY_ANNOTATIONS_ANNOTATION_UNSPECIFIED = 0;
    SAFETY_ANNOTATIONS_SPAMMER = 1;
    SAFETY_ANNOTATIONS_SELF_DELETED = 2;
    SAFETY_ANNOTATIONS_SELF_DISABLED = 3;
    SAFETY_ANNOTATIONS_UNDERAGE_DELETED = 4;
    SAFETY_ANNOTATIONS_SAFETY_POLICY_VIOLATION = 5;
    SAFETY_ANNOTATIONS_INACTIVITY_DELETED = 6;
    SAFETY_ANNOTATIONS_GENERIC_DELETED = 7;
  }

  message SafetyState {
    oneof state {
      NormalState normal = 101;
      RestrictedState restricted = 102;
      DeferredActionState deferred_action = 103;
      TempBannedState temp_banned = 104;
      BannedState banned = 105;
    }
    SafetyStateReason reason = 1;
    repeated SafetyAnnotations annotations = 2;
    optional google.protobuf.UInt64Value last_mutation_id = 3;
  }

  enum PremiumSource {
    PREMIUM_SOURCE_NONE_UNSPECIFIED = 0;
    PREMIUM_SOURCE_SUBSCRIPTION = 1;
    PREMIUM_SOURCE_FRACTIONAL_NITRO = 2;
    PREMIUM_SOURCE_REVERSE_TRIAL = 3;
    PREMIUM_SOURCE_SUBSCRIPTION_GROUP = 4;
  }

  enum PremiumSubscriptionType {
    PREMIUM_SUBSCRIPTION_TYPE_NONE_UNSPECIFIED = 0;
    PREMIUM_SUBSCRIPTION_TYPE_BOOST_ONLY = 1;
    PREMIUM_SUBSCRIPTION_TYPE_TIER_0 = 2;
    PREMIUM_SUBSCRIPTION_TYPE_TIER_1 = 3;
    PREMIUM_SUBSCRIPTION_TYPE_TIER_2 = 4;
  }

  enum PremiumSubscriptionGroupRole {
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_UNSPECIFIED = 0;
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_PRIMARY = 1;
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_MEMBER = 2;
  }

  message PremiumState {
    PremiumSource premium_source = 1;
    PremiumSubscriptionType premium_subscription_type = 2;
    PremiumSubscriptionGroupRole premium_subscription_group_role = 3;
  }

  enum DisplayNameFont {
    DISPLAY_NAME_FONT_UNSPECIFIED = 0;
    DISPLAY_NAME_FONT_DEFAULT = 11;
    DISPLAY_NAME_FONT_BANGERS = 1;
    DISPLAY_NAME_FONT_BIO_RHYME = 2;
    DISPLAY_NAME_FONT_CHERRY_BOMB = 3;
    DISPLAY_NAME_FONT_CHICLE = 4;
    DISPLAY_NAME_FONT_COMPAGNON = 5;
    DISPLAY_NAME_FONT_MUSEO_MODERNO = 6;
    DISPLAY_NAME_FONT_NEO_CASTEL = 7;
    DISPLAY_NAME_FONT_PIXELIFY = 8;
    DISPLAY_NAME_FONT_RIBES = 9;
    DISPLAY_NAME_FONT_SINISTRE = 10;
    DISPLAY_NAME_FONT_ZILLA_SLAB = 12;
  }

  enum DisplayNameEffect {
    DISPLAY_NAME_EFFECT_UNSPECIFIED = 0;
    DISPLAY_NAME_EFFECT_SOLID = 1;
    DISPLAY_NAME_EFFECT_GRADIENT = 2;
    DISPLAY_NAME_EFFECT_NEON = 3;
    DISPLAY_NAME_EFFECT_TOON = 4;
    DISPLAY_NAME_EFFECT_POP = 5;
    DISPLAY_NAME_EFFECT_GLOW = 6;
  }

  message DisplayNameStyles {
    DisplayNameFont font_id = 1;
    DisplayNameEffect effect_id = 2;
    repeated uint32 colors = 3;
  }

  message StoreCountry {
    string country = 1;
    optional google.protobuf.Timestamp set_at = 2;
  }

  message TimeOfDay {
    int32 hours = 1;
    int32 minutes = 2;
    int32 seconds = 3;
    int32 nanos = 4;
  }

  enum DayOfWeek {
    DAY_OF_WEEK_UNSPECIFIED = 0;
    DAY_OF_WEEK_MONDAY = 1;
    DAY_OF_WEEK_TUESDAY = 2;
    DAY_OF_WEEK_WEDNESDAY = 3;
    DAY_OF_WEEK_THURSDAY = 4;
    DAY_OF_WEEK_FRIDAY = 5;
    DAY_OF_WEEK_SATURDAY = 6;
    DAY_OF_WEEK_SUNDAY = 7;
  }

  message ScheduleRule {
    string rule_id = 1;
    string label = 2;
    optional TimeOfDay start_time = 3;
    optional TimeOfDay end_time = 4;
    repeated DayOfWeek days = 5;
  }

  message RestrictedSchedule {
    repeated ScheduleRule rules = 1;
  }

  enum AgeAssuranceMethod {
    AGE_ASSURANCE_METHOD_UNSPECIFIED = 0;
    AGE_ASSURANCE_METHOD_ID_SELFIE_MATCH = 1;
    AGE_ASSURANCE_METHOD_ID_SCAN = 2;
    AGE_ASSURANCE_METHOD_FACIAL_AGE_ESTIMATION = 3;
    AGE_ASSURANCE_METHOD_BEHAVIORAL_INFERENCE = 4;
    AGE_ASSURANCE_METHOD_CREDIT_CARD = 5;
    AGE_ASSURANCE_METHOD_EMAIL_DOMAIN = 6;
    AGE_ASSURANCE_METHOD_OS_SIGNAL = 7;
    AGE_ASSURANCE_METHOD_ML_AGE_INFERENCE = 8;
  }

  enum AgeAssuranceVendor {
    AGE_ASSURANCE_VENDOR_UNSPECIFIED = 0;
    AGE_ASSURANCE_VENDOR_K_ID = 1;
    AGE_ASSURANCE_VENDOR_PERSONA = 2;
    AGE_ASSURANCE_VENDOR_INCODE = 3;
    AGE_ASSURANCE_VENDOR_DISCORD = 4;
  }

  message AgeAssuranceData {
    optional google.protobuf.Timestamp estimated_date_of_birth = 1;
    AgeAssuranceMethod method = 2;
    int32 method_version = 3;
    AgeAssuranceVendor vendor = 4;
    optional google.protobuf.Timestamp verified_at = 5;
  }

  enum PerkSource {
    PERK_SOURCE_SOURCE_UNSPECIFIED = 0;
    PERK_SOURCE_SOURCE_NITRO = 1;
    PERK_SOURCE_SOURCE_THIRDPARTY_CROISSANT = 2;
  }

  message PerkConfigIncreasedFileUploadSize {
    uint64 max_size = 1;
  }

  message PerkConfigIncreasedGuildLimit {
    uint32 max_guilds = 1;
  }

  message PerkConfig {
    oneof kind {
      PerkConfigIncreasedFileUploadSize increased_file_upload_size = 2;
      PerkConfigIncreasedGuildLimit increased_guild_limit = 3;
    }
    repeated PerkSource source = 1;
  }

  message Perks {
    repeated uint64 active_perks_bitmask = 1;
    map<uint32, PerkConfig> config_by_perk = 2;
    uint32 rules_version = 3;
    optional google.protobuf.Timestamp updated_at = 4;
  }

  message BadgeCommon {
    optional google.protobuf.Timestamp obtained_at = 1;
  }

  message AprilFools2026Badge {
    optional BadgeCommon common = 1;
    int32 level = 2;
    string combat_class = 3;
  }

  message Badge {
    oneof badge {
      AprilFools2026Badge april_fools_2026 = 1;
    }
  }

  message UserBadges {
    repeated Badge badges = 1;
  }

  map<fixed64, LinkedUser> linked_users = 1;
  map<uint32, FeatureLimits> safety_feature_limits = 2;
  map<uint32, SafetyFlag> safety_flags = 3;
  optional QuestMetadata quest = 4;
  optional UserPrimaryGuild primary_guild = 5;
  optional CrossPlatformRestriction cross_platform_restriction = 6;
  optional UserCollectibles collectibles = 7;
  optional SafetyState safety_state = 8;
  optional PremiumState premium_state = 9;
  optional DisplayNameStyles display_name_styles = 10;
  optional StoreCountry store_country = 11;
  optional RestrictedSchedule restricted_schedule = 12;
  optional AgeAssuranceData age_assurance_data = 13;
  optional Perks perks = 14;
  optional UserBadges badges = 15;
}
