"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class GuildShardingConfig(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    SHARDS_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def shards(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
    def __init__(
        self,
        *,
        shards: _abc.Iterable[_builtins.int] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["shards", b"shards"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GuildShardingConfig: _TypeAlias = GuildShardingConfig  # noqa: Y015
