# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: discord_kkv_store_value_models/v1/ApplicationUserRoleConnection.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'discord_kkv_store_value_models/v1/ApplicationUserRoleConnection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEdiscord_kkv_store_value_models/v1/ApplicationUserRoleConnection.proto\x12\x30\x64iscord_protos.discord_kkv_store_value_models.v1\"\x84\x02\n\x1d\x41pplicationUserRoleConnection\x12o\n\x08metadata\x18\x01 \x03(\x0b\x32].discord_protos.discord_kkv_store_value_models.v1.ApplicationUserRoleConnection.MetadataEntry\x12\x15\n\rplatform_name\x18\x02 \x01(\t\x12\x19\n\x11platform_username\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x06\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discord_kkv_store_value_models.v1.ApplicationUserRoleConnection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_APPLICATIONUSERROLECONNECTION_METADATAENTRY']._loaded_options = None
  _globals['_APPLICATIONUSERROLECONNECTION_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_APPLICATIONUSERROLECONNECTION']._serialized_start=124
  _globals['_APPLICATIONUSERROLECONNECTION']._serialized_end=384
  _globals['_APPLICATIONUSERROLECONNECTION_METADATAENTRY']._serialized_start=337
  _globals['_APPLICATIONUSERROLECONNECTION_METADATAENTRY']._serialized_end=384
# @@protoc_insertion_point(module_scope)
